@@ -10,17 +10,18 @@
 
 #include "mapchooser.h"
 
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
-#include <klistwidgetsearchline.h>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KListWidgetSearchLine>
 
-#include <qdir.h>
-#include <qimage.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qlistwidget.h>
-#include <qdialogbuttonbox.h>
-#include <qpushbutton.h>
+#include <QDir>
+#include <QImage>
+#include <QLabel>
+#include <QLayout>
+#include <QListWidget>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QSet>
 
 #include <algorithm>
 
@@ -65,12 +66,17 @@ mapChooser::mapChooser(QWidget *parent) : QDialog(parent)
 	QString lastMapFile = kgeographySettings::self() -> lastMap();
 	QString stringToSelect;
 	QStringList texts;
+	QSet<QString> loadedMaps;
 	const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::DataLocation, QLatin1String(""), QStandardPaths::LocateDirectory);
 	foreach (const QString &dir, dirs)
 	{
 		const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.kgm"));
 		foreach (const QString &file, fileNames)
 		{
+			// avoid multiple and should guarantee that first in XDG_DATA_DIRS is chosen)
+			if (loadedMaps.contains(file))
+				continue;
+
 			QString mapFilename = dir + '/' + file;
 
 			KGmap *m = p_reader.parseMap(mapFilename);
@@ -78,16 +84,20 @@ mapChooser::mapChooser(QWidget *parent) : QDialog(parent)
 				errorTexts << i18n("Error parsing %1: %2", mapFilename, p_reader.getError());
 			else
 			{
-				QString text = i18nc(m->getFileName().toUtf8(), m->getName().toUtf8());
-				// avoid multiple and should guarantee that first in XDG_DATA_DIRS is chosen)
-				if (texts.contains(text))
+				QString text = m -> getName();
+				KGmap* existingMap = p_maps.value(text);
+				if (existingMap)
+				{
+					errorTexts << i18n("The map %1 has the same name of map %2", mapFilename, existingMap -> getFile());
 					delete m;
+				}
 				else
 				{
 					texts << text;
 					p_maps.insert(text, m);
 					if ( mapFilename == lastMapFile )
 						stringToSelect = text;
+					loadedMaps << file;
 				}
 			}
 		}
